#!/bin/bash

if [ "$IMAGE_TAG" == "" ]; then
  echo "Make sure IMAGE_TAG is set"
  exit 1
fi


IMAGE_NAME=gitea.hottis.de/wn/locsrv
NAMESPACE=homea
DEPLOYMENT_DIR=$PWD/deployment

pushd $DEPLOYMENT_DIR > /dev/null
./decrypt-secrets.sh || exit 1 
. /tmp/secrets
rm /tmp/secrets

kubectl create namespace $NAMESPACE \
  --dry-run=client \
  -o yaml | \
  kubectl -f - apply

kubectl create secret generic locsrv-db-cred \
  --dry-run=client \
  -o yaml \
  --save-config \
  --from-literal=PGUSER="$PGUSER" \
  --from-literal=PGPASSWORD="$PGPASSWORD" \
  --from-literal=PGDATABASE="$PGDATABASE" \
  --from-literal=PGHOST="timescaledb.database.svc.cluster.local" \
  --from-literal=PGSSLMODE="require" | \
  kubectl apply -f - -n $NAMESPACE

cat $DEPLOYMENT_DIR/deploy-yml.tmpl | \
  sed -e 's,%IMAGE%,'$IMAGE_NAME':'$IMAGE_TAG','g | \
  kubectl apply -f - -n $NAMESPACE

popd > /dev/null

