package main

import (
  "log"
  "time"
  "fmt"
  "net/http"
  "encoding/json"
  "locsrv/database"
  "locsrv/mqtt"
)

/*
{
  "trigger":"enter",
  "device":"aaaaaaaa-bbbb-cccc-dddd-eeeeeeeeeeee",
  "device_model":"iPhone13,1",
  "timestamp":"1705162497.0",
  "latitude":"51.0",
  "id":"test",
  "longitude":"7.0",
  "device_type":"iPhone"
}
*/

type locativeEvent struct {
  Trigger string `json:"trigger"`
  Device string `json:"device"`
  Location string `json:"location"`
  Latitude string `json:"latitude"`
  Longitude string `json:"longitude"`
  Person string `json:"person"`
  Timestamp string `json:"timestamp"`
}


func main() {
  ch := make(chan locativeEvent)
  dbh := database.New()
  mqtt := mqtt.New()

  go func() {
    for {
      select {
      case event := <- ch:
        person, err := dbh.GetPersonById(event.Device)
        event.Person = person
        event.Timestamp = time.Now().Format("2006-01-02 15:04:05 MST")
        if err != nil {
          log.Printf("Person unknown: %v", err)
        } 
        message, err2 := json.Marshal(event)
        if err2 != nil {
          log.Printf("Unable to marshal event: %v", err2)
        } else {
          log.Printf("Message: %s", message)
          err := mqtt.Publish(person, string(message))
          if err != nil {
            log.Printf("Failed to publish: %v", err)
          }
        }
      }
    }
  }()

  http.HandleFunc("/location", func(resp http.ResponseWriter, req *http.Request) {
    err1 := req.ParseForm()
    if err1 != nil {
      log.Printf("Failed to parse request: %v", err1)
      http.Error(resp, "Failed to parse request", http.StatusBadRequest)
      return
    }

    var event locativeEvent
    event.Trigger = req.Form.Get("trigger")
    event.Device = req.Form.Get("device")
    event.Location = req.Form.Get("id")
    event.Latitude = req.Form.Get("latitude")
    event.Longitude = req.Form.Get("longitude")

    select {
    case ch <- event:
      resp.WriteHeader(http.StatusOK)
      fmt.Fprintf(resp, "Message forwarded")
      return
    default:
      log.Printf("Channel full, message lost")
      http.Error(resp, "Channel full, message lost", http.StatusServiceUnavailable)
      return
    }

  })

  err := http.ListenAndServe(":8080", nil)
  if err != nil {
    log.Fatalf("Failed to start server: %v", err)
  }
}

